#!/bin/bash


# Create LaTeX-files that shows certain Japanese char in many fonts

# Author:
# Juhapekka Tolvanen
# http://iki.fi/juhtolv
# juhtolv (at) iki (dot) fi

# This script is public domain. There is no warranty.

# Usage:
# compile_subgroup.sh GROUP SUBGROUP
# Example usage:
# compile_subgroup.sh hiragana basic
# (In that case it tries to include ./rc.hiragana_basic.sh)

CHARMAP="`locale charmap`"

if test "$CHARMAP" == "UTF-8"
then
    echo "Your environment is UTF-8-safe"
else
    echo "Your environment is not UTF-8-safe"
    exit 1
fi

# Some (l)user-serviceable environment variables are in that file
# called fontsamples.rc.sh

if . ./fontsamples.rc.sh
then
    :
else
    echo "./fontsamples.rc.sh could not be read" 
    exit 1
fi

cd ${WORKDIR} || exit 1

if . ./checkworkdirs.sh
then
    :
else
    echo "./checkworkdirs.sh could not be read" 
    exit 1
fi

if . ./rc.${1}_${2}.sh
then
    :
else
    echo "./rc.${1}_${2}.sh could not be read"
    exit 1
fi

export GROUP
export SUBGROUP

cd ${WORKDIR} || exit 1

for FORMAT in pdf tex
do
    echo "mkdir -pv ./${FORMAT}/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}"
    mkdir -pv ./${FORMAT}/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}

    echo "mkdir -pv ./${FORMAT}-tmp/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}"
    mkdir -pv ./${FORMAT}-tmp/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}

done

    ### Those files in that directory called progress can be used by
    ### any software that monitors progress running these scripts. But
    ### these files are not usefull, if you compile more than one
    ### subgroup simultaneously
    echo "mkdir ./progress"
    mkdir ./progress
    rm -f ./progress/GROUP
    echo ${GROUP} > ./progress/GROUP
    rm -f ./progress/SUBGROUP
    echo ${SUBGROUP} > ./progress/SUBGROUP


M="0"
for f in `echoallchars`
do
    printf ${f}
    M="$(( ${M} + 1 ))"
    export M
done
echo ""
echo "M=${M}"

N="0"
for g in `echoallchars`
do
    N="$(( ${N} + 1 ))"
    echo "${N}/${M}: ${g}"
    ### Note: That script does absolutely nothing with that "${N}/${M}".
    ### They are used just because I wanted to see progress of subgroup
    ### from output of ps-command.

    ### Those files in that directory called progress can be used by
    ### any software that monitors progress running these scripts. But
    ### these files are not usefull, if you compile more than one
    ### subgroup simultaneously
    rm -f ./progress/N
    echo ${N} > ./progress/N
    rm -f ./progress/M
    echo ${M} > ./progress/M
    rm -f ./progress/g
    echo ${g} > ./progress/g
    CURRUCS="`unicode --colour=off ${g} | head -n 1`"
    rm -f ./progress/CURRUCS
    echo "${CURRUCS}" > ./progress/CURRUCS


    case $GROUP in
        *kanji*)
        if test "$UNIHAN" = "true"
        then
            echo ./createtexfile_kanji_unihan.sh "${g}" "${GROUP}" "${SUBGROUP}" "${N}/${M}"
            ./createtexfile_kanji_unihan.sh "${g}" "${GROUP}" "${SUBGROUP}" "${N}/${M}"
        else
            echo "./createtexfile_kanji.sh ${g} ${GROUP} ${SUBGROUP}" "${N}/${M}"
            ./createtexfile_kanji.sh "${g}" "${GROUP}" "${SUBGROUP}" "${N}/${M}"
        fi
        ;;
        *)
        echo "./createtexfile.sh ${g} ${GROUP} ${SUBGROUP}" "${N}/${M}"
        ./createtexfile.sh "${g}" "${GROUP}" "${SUBGROUP}" "${N}/${M}"
    esac

done

rm -rfv ./progress

for FORMAT in pdf tex
do
    cd ${WORKDIR}/${FORMAT}/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}/
    for f in *
    do
        rm -f ${f}
    done 

    cd ${WORKDIR}/${FORMAT}-tmp/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}/
    for f in *
    do
        mv -f ${f} ${WORKDIR}/${FORMAT}/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}/
    done
    cd ${WORKDIR}
    rmdir ${WORKDIR}/${FORMAT}-tmp/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}
done


for FORMAT in pdf tex
do
    cd ${WORKDIR}/${FORMAT}/${GROUP}/

    ### XXX: I have tested du of GNU coreutils and Heirloom Toolchest
    ### XXX: Only du of GNU coreutils can do this:
    touch ${WORKDIR}/du_files/du_catenate_B.txt
    du -s -b ${GROUP}_${SUBGROUP}_${FORMAT} >> ${WORKDIR}/du_files/du_catenate_B.txt

    touch ${WORKDIR}/du_files/du_catenate_kB.txt
    du -s -k ${GROUP}_${SUBGROUP}_${FORMAT} >> ${WORKDIR}/du_files/du_catenate_kB.txt

    ### XXX: Only du of GNU coreutils can do this:
    touch ${WORKDIR}/du_files/du_catenate_MB.txt
    du -s -m ${GROUP}_${SUBGROUP}_${FORMAT} >> ${WORKDIR}/du_files/du_catenate_MB.txt

    ### XXX: Only du of GNU coreutils and Heirloom Toolchest can do this:
    touch ${WORKDIR}/du_files/du_catenate_human.txt
    du -s -h ${GROUP}_${SUBGROUP}_${FORMAT} >> ${WORKDIR}/du_files/du_catenate_human.txt

    rm -f ${WORKDIR}/index/${GROUP}_${SUBGROUP}_${FORMAT}.txt 2> /dev/null
    touch ${WORKDIR}/index/${GROUP}_${SUBGROUP}_${FORMAT}.txt
    ls ${GROUP}_${SUBGROUP}_${FORMAT} >> ${WORKDIR}/index/${GROUP}_${SUBGROUP}_${FORMAT}.txt 

done

# It is practically impossible to sort du_sorted_human.txt
# Other du-files are sorted
cd ${WORKDIR}/du_files

rm -f du_sorted_B.txt
touch du_sorted_B.txt
sort -nr du_catenate_B.txt >> du_sorted_B.txt

rm -f du_sorted_kB.txt
touch du_sorted_kB.txt
sort -nr du_catenate_kB.txt >> du_sorted_kB.txt

rm -f du_sorted_MB.txt
touch du_sorted_MB.txt
sort -nr du_catenate_MB.txt >> du_sorted_MB.txt


rm -f ${WORKDIR}/index/ALL_index.txt
touch ${WORKDIR}/index/ALL_index.txt
rm -f ${WORKDIR}/index/PDF_index.txt
touch ${WORKDIR}/index/PDF_index.txt
rm -f ${WORKDIR}/index/TEX_index.txt
touch ${WORKDIR}/index/TEX_index.txt

cd ${WORKDIR}/index/ || exit 1
echo "" >> ALL_index.txt
echo "" >> ALL_index.txt

for g in *_*_*.txt
do
    echo '############################################################################' >> ALL_index.txt
    echo '###'" ${g}" >> ALL_index.txt
    echo '###' >> ALL_index.txt
    cat "${g}" >> ALL_index.txt
    echo "" >> ALL_index.txt
    echo "" >> ALL_index.txt
done
echo "" >> ALL_index.txt
echo "EOF" >> ALL_index.txt

for g in *_*_pdf.txt
do
    echo '############################################################################' >> PDF_index.txt
    echo '###'" ${g}" >> PDF_index.txt
    echo '###' >> PDF_index.txt
    cat "${g}" >> PDF_index.txt
    echo "" >> PDF_index.txt
    echo "" >> PDF_index.txt
done
echo "" >> PDF_index.txt
echo "EOF" >> PDF_index.txt

for g in *_*_tex.txt
do
    echo '############################################################################' >> TEX_index.txt
    echo '###'" ${g}" >> TEX_index.txt
    echo '###' >> TEX_index.txt
    cat "${g}" >> TEX_index.txt
    echo "" >> TEX_index.txt
    echo "" >> TEX_index.txt
done
echo "" >> TEX_index.txt
echo "EOF" >> TEX_index.txt


touch ${WORKDIR}/pdfpages.txt

cd ${WORKDIR}/pdf/${GROUP}/${GROUP}_${SUBGROUP}_pdf
for y in *.pdf
do
    pdfinfo "${y}" | egrep '^Pages:'
done | sort | uniq >> ${WORKDIR}/pdfpages.txt

cd ${WORKDIR}
sort pdfpages.txt | uniq >> pdfpages_2.txt
mv -f pdfpages_2.txt pdfpages.txt


# -*- coding: utf-8 -*-

# Local Variables: ***
# mode:Shell-script ***
# coding: utf-8 ***
# End: ***

# vim: set ft=sh fenc=utf-8 :

