#!/bin/bash

# Author:
# Juhapekka Tolvanen
# http://iki.fi/juhtolv
# juhtolv (at) iki (dot) fi

# This file is public domain. There is no warranty.

# Usage:
# compress_subgroup.sh GROUP SUBGROUP
# Example usage:
# compress_subgroup.sh hiragana basic
# (In that case it tries to include ./rc.hiragana_basic.sh)


# Some (l)user-serviceable environment variables are in that file
# called fontsamples.rc.sh

if . ./fontsamples.rc.sh
then
    :
else
    echo "./fontsamples.rc.sh could not be read" 
    exit 1
fi

cd ${WORKDIR} || exit 1

if . ./checkworkdirs.sh
then
    :
else
    echo "./checkworkdirs.sh could not be read" 
    exit 1
fi

if . ./rc.${1}_${2}.sh
then
    :
else
    echo "./rc.${1}_${2}.sh could not be read"
    exit 1
fi


export GROUP
export SUBGROUP
export TEXCOMPRMETHOD
export TEXSEVENZIPOPTS
export PDFCOMPRMETHOD
export PDFSEVENZIPOPTS


mytarbztwo()
{
    echo "$TAR_BIN -c -f - ${1} | bzip2 -9 > ${1}.tar.bz2"
    $TAR_BIN -c -f - ${1} | bzip2 -9 > ${1}.tar.bz2
}

mytexsevenzip()
{
    case $TEXSEVENZIPOPTS in
        1)
        echo "$SEVENZIP_BIN a $SEVENZIPOPTSONE ${1}.7z ${1}"
        $SEVENZIP_BIN a $SEVENZIPOPTSONE ${1}.7z ${1}
        ;;
        2)
        echo "$SEVENZIP_BIN a $SEVENZIPOPTSTWO ${1}.7z ${1}"
        $SEVENZIP_BIN a $SEVENZIPOPTSTWO ${1}.7z ${1}
        ;;
        *)
        echo "${0} ${1} ${2}: "'WTF? What is TEXSEVENZIPOPTS called '"$TEXSEVENZIPOPTS"
    esac
}

mypdfsevenzip()
{
    case $PDFSEVENZIPOPTS in
        1)
        echo "$SEVENZIP_BIN a $SEVENZIPOPTSONE ${1}.7z ${1}"
        $SEVENZIP_BIN a $SEVENZIPOPTSONE ${1}.7z ${1}
        ;;
        2)
        echo "$SEVENZIP_BIN a $SEVENZIPOPTSTWO ${1}.7z ${1}"
        $SEVENZIP_BIN a $SEVENZIPOPTSTWO ${1}.7z ${1}
        ;;
        *)
        echo "${0} ${1} ${2}: "'WTF? What is PDFSEVENZIPOPTS called '"$TEXSEVENZIPOPTS"
    esac
}


for FORMAT in pdf tex
do
    if test -d ${WORKDIR}/${FORMAT}/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}
then
    echo ${FORMAT}/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}
    cd ${WORKDIR}/${FORMAT}/${GROUP}
    chmod ugo+rx,go-w ${GROUP}_${SUBGROUP}_${FORMAT}
    chmod ugo+r,ugo-x,go-w ${GROUP}_${SUBGROUP}_${FORMAT}/*
    rm -f ${GROUP}_${SUBGROUP}_${FORMAT}.tar.bz2 ${GROUP}_${SUBGROUP}_${FORMAT}.7z
    case $FORMAT in
        tex)
        case $TEXCOMPRMETHOD in
            tarbztwo)
            mytarbztwo "${GROUP}_${SUBGROUP}_${FORMAT}" \
            && rm -rf "${GROUP}_${SUBGROUP}_${FORMAT}"
            ;;
            sevenzip)
            mytexsevenzip "${GROUP}_${SUBGROUP}_${FORMAT}" \
            && rm -rf "${GROUP}_${SUBGROUP}_${FORMAT}"
            ;;
            *)
            echo "${0} ${1} ${2}: "'WTF? What is TEXCOMPRMETHOD called '"$TEXCOMPRMETHOD"
        esac
        ;;

        pdf)
        case $PDFCOMPRMETHOD in
            tarbztwo)
            mytarbztwo "${GROUP}_${SUBGROUP}_${FORMAT}" \
            && rm -rf "${GROUP}_${SUBGROUP}_${FORMAT}"
            ;;
            sevenzip)
            mypdfsevenzip "${GROUP}_${SUBGROUP}_${FORMAT}" \
            && rm -rf "${GROUP}_${SUBGROUP}_${FORMAT}"
            ;;
            *)
            echo "${0} ${1} ${2}:"'WTF? What is PDFCOMPRMETHOD called '"$PDFCOMPRMETHOD"
        esac
        ;;

        *)
        echo  "${0} ${1} ${2}: " 'WTF? What is FORMAT called '"$FORMAT"
    esac
else
    echo "${0} ${1} ${2}: ${FORMAT}/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT} do not exist."
fi
done



# Local Variables: ***
# mode:Shell-script ***
# coding: utf-8 ***
# End: ***

# vim: set ft=sh fenc=utf-8 :


