#!/bin/bash

# Local Variables: ***
# mode: Shell-script ***
# coding: utf-8 ***
# End: ***

# createtexfile.sh
# Create LaTeX-file that shows certain Japanese char in many fonts
# Compile it and move to right directory.

# Author:
# Juhapekka Tolvanen
# http://iki.fi/juhtolv
# juhtolv (at) iki (dot) fi

# This script is public domain. There is no warranty.

# Usage:
# createtexfile.sh (character) GROUP SUBGROUP
# Example: 
# createtexfile.sh あ hiragana basic


CHARMAP="`locale charmap`"

if test "$CHARMAP" == "UTF-8"
then
    echo "Your environment is UTF-8-safe"
else
    echo "Your environment is not UTF-8-safe"
    exit 1
fi

if test \("$1" = ""\) -o \("$2" = ""\) -o \("$3" = ""\) -o \( "$#" -lt 3 \)
then
    echo "Usage:"
    echo "$0 (character) (group) (subgroup)"
    echo "Example: $0 あ hiragana basic"
    exit 1
fi

CURRCHAR="${1}"

echo CURRCHAR=${CURRCHAR}

CURRUCS="`unicode --colour=off ${1} | head -n 1`"

echo CURRUCS=${CURRUCS}

CURRVAL="`unicode --colour=off ${1} | head -n 1 | awk '{print $1}'`"

echo CURRVAL=${CURRVAL}

FILENAME="${CURRVAL}.tex"

# Starting LaTeX-file (do not strip comments)
cp -f fontsamples_top.tex ${FILENAME}
# More starting LaTeX-file (strip comments)
cat fontsamples_start.tex | egrep -v '^%' >> ${FILENAME}

# All that stuff that depends on environment variables
printf '%b\\title{{\\Large\\textsf{' >> ${FILENAME}
printf ${CURRCHAR} >> ${FILENAME}
printf ' ' >> ${FILENAME}
printf "${CURRUCS}" >> ${FILENAME}
printf '%b}}}\n' >> ${FILENAME}

echo "" >> ${FILENAME}
echo '\date{}' >> ${FILENAME}
echo '\author{}' >> ${FILENAME}
echo '\maketitle' >> ${FILENAME}
echo '\thispagestyle{empty}' >> ${FILENAME}
echo ""  >> ${FILENAME}

echo '\ \\' >> ${FILENAME}
#echo '\vspace{-3cm}' >> ${FILENAME}
echo '\vspace{-3.1cm}' >> ${FILENAME}
echo '\enlargethispage*{3\baselineskip}' >> ${FILENAME}
printf '%b\\myshowallfonts{' >> ${FILENAME}
printf ${CURRCHAR} >> ${FILENAME}
printf '%b}\n' >> ${FILENAME}
echo ""  >> ${FILENAME}
echo "\fussy" >> ${FILENAME}
echo ""  >> ${FILENAME}
echo '\ \\' >> ${FILENAME}

if test ! -f ./mydate.txt
then
    ./mydate.sh
fi

MYDATE="`cat ./mydate.txt`"
echo "\texttt{${MYDATE}"  >> ${FILENAME}

# Ending LaTeX (strip comments)
cat fontsamples_end.tex | egrep -v '^%' >> ${FILENAME}

# Some important comments to the end of file (we do not want to strip them):
cat fontsamples_bottom.tex >> ${FILENAME}

# And now let’s run XeLaTeX
xelatex -src-specials -file-line-error-style ${FILENAME}
while grep 'Rerun to get' ${CURRVAL}.log > /dev/null
do
    xelatex -src-specials -file-line-error-style ${FILENAME}S
done

if grep Overfull ${CURRVAL}.log > /dev/null
then
    touch overfull_list.txt
    echo ${CURRVAL}.pdf >> overfull_list.txt
fi


mv -fv ${CURRVAL}.tex ./tex-tmp/${2}/${2}_${3}_tex/
mv -fv ${CURRVAL}.pdf ./pdf-tmp/${2}/${2}_${3}_pdf/

rm -fv ${CURRVAL}.log
rm -fv ${CURRVAL}.aux


# -*- coding: utf-8 -*-

# Local Variables: ***
# mode: Shell-script ***
# coding: utf-8 ***
# End: ***

# vim: set ft=sh fenc=utf-8 :
